* **************************************************************************** *
* **************************************************************************** *
* Breadwinners and Caregivers: Examining the Global Relationship between       *
* Gender Norms and Economic Behavior                                           *
* Replication File                                                             *
* PART 1: Master Dofile for Data Variable Cleaning                             *
* 2024                                                                         *
* **************************************************************************** *
* **************************************************************************** *
/*
* Author: Paula Gonzalez
* Program Purpose: This master dofile is designed to import the raw dataset 
*                   from the 'Gender at Home' project. After importing into stata, 
                    this dofile cleans and prepare the data for variable construction. 
* Description: Key tasks performed by this dofile include:
- Adding value and variable lables 
- Deals with special missing values (i.e. .d=Dont know)
- Converts string to numeric variables when needed
- Sample selection: restricts the data to the sample we can use for our analysis.  

* Date last reviewed: February 2024
*------------------------------------------------------------------------------*
* Datasets Required: 
* - Data 1 data_v3_sogeh_microdata_2020: Third version of raw data. 
*
* Unique Identifier: 
* - The dataset has been de-identified in line with the agreement with Facebook. 
*   It includes only country-level codes and no individual identifiers.
*
* Outline: 
*  Part 1. Importing the data into excel 
*  Part 2. General cleaning 
*  Part 3. Extra cleaning of invidiual variables 
*/

********************************************************************************
*                       PREPARATION AND MAIN SETTINGS 
********************************************************************************
if 1{
* Index of parts
* -----------------  
  gl part_1    0    /* Importing facebook excel data -
                       Do not run everytime because it takes a while and changes the original names.
					   This should be just be run once by Paula*/
					
  gl part_2    1    // General Cleaning data 
  gl part_3    1    // Cleaning individual variables
  
}


********************************************************************************
*                  PART 1. Importing data form excel 
********************************************************************************
if $part_1{
** Importing original raw data shared by Facebook  
   import delimited "$data\Raw\Third Revision\data_v3_sogeh_microdata_2020.xlsx", firstrow clear
    
** We need to do a few manual changes in the editor that can't be done with coding 
   saveold  "$data\Raw\GenderAtHomeDataRaw_092021.dta", replace 
  }
  
********************************************************************************
*                       PART 2. General Cleaning 
********************************************************************************
if $part_2{ 
* Load Dataset 
  use  "$data\Raw\GenderAtHomeDataRaw_092021.dta", clear 

  # d;
  label def likert_scale
        1 "Strongly Agree"
		2 "Agree"
		3 "Neither"
		4 "Disagree"
		5 "Strongly Disagree", modify;	
  # d cr;
  
  # d;
  label def yesno
        0 "No"
		1 "Yes", modify;	
  # d cr;


  label val a1 likert_scale
  label var a1 "Men and women should have equal opportunity"

  label var a2_opps_other "How many of your neighbors believe that men and women should have equal opportun"

  label val a3 yesno
  label var a3 "Last week, did you do any work for pay, do any kind of business, farming or othe"

  # d;
  label def gender
        1 "Female"
		2 "Male"
		3 "Other", modify;
  # d cr;
  label val a4 gender
  label var a4 "Gender"
  
  # d;
  label def relation_hhh
        1 "Head of Household"
		2 "Spouse or partner"
		3 "Child or Grandchild"
		4 "Other", modify;
  # d cr;
  label val a5_r1 relation_hhh
  label var a5_r1 "Relationship to Head of Household - Recoded"
  
  # d;
  label def urbanicity
        1 "City"
		2 "Village, rural area, or other", modify;
  # d cr;
  label val a6_r urbanicity
  label var a6_r "Urbanicity - Recoded"

  label val b10 yesno
  label var b10 "Food insecurity in last 10 day b/c of lack of money or resources"
  
  label var b1_hours_work "Number of hours spent per day at work last week"

  label var b2_main_earners_brother "Brother is the main income earner"

  label var b2_main_earners_daughter "Daughter is the main income earner"

  label var b2_main_earners_father "Father is the main income earner"

  label var b2_main_earners_mother "Mother is the main income earner"

  label var b2_main_earners_other "The main income earner is: Other"

  label var b2_main_earners_othman "The main income earner: Other man"

  label var b2_main_earners_othwoman "The main income earner: Other woman"

  label var b2_main_earners_self "The main income earner: Self"

  label var b2_main_earners_sister "Sister is the main income earner"

  label var b2_main_earners_son "Son is the main income earner"

  label var b2_main_earners_spouse "Spouse is the main income earner"

  # d;
  label def econ_depend
        1 "I fully depend on someone else in my HH"
		2 "I partially depend on someone else in HH"
		3 "I fully cover my own expenses"
		4 "I fully cover only my own expenses and that of other HH members"
		5 "I fully cover all living expenses for HH"
		6 "Other(specify)", modify;	
  # d cr;
  label val b3 econ_depend
  label var b3 "Role in coverage of living expediture of household"
  
  label val b4 likert_scale
  label var b4 "household expenses are the responsibility of the man, even if his wife can help him"
  
  label var b5_man_other "How many neighbs believe expenses are man responsib, even if wife can help"
  
  label var b6_livelihood_assistance "HH Source of livelihood: Assistance from family in country"
  
  label var b6_livelihood_familybiz "HH Source of livelihood: family business (not farming)"
  
  label var b6_livelihood_familyfarm "HH Source of livelihood: Family farming"
  
  label var b6_livelihood_gov "HH Source of livelihood: Gov. Assistance"
  
  label var b6_livelihood_invest "HH Source of livelihood: income properties"
  
  label var b6_livelihood_ngo "HH Source of livelihood: NGO Assistance"
  
  label var b6_livelihood_nonfam "HH Source of livelihood: Assistance from non-family members"
  
  label var b6_livelihood_oth "HH Source of livelihood: Other(specify)"
  
  label var b6_livelihood_pension "HH Source of livelihood: Pension"
  
  label var b6_livelihood_remittances "HH Source of livelihood: remittances from abroad"

  label var b6_livelihood_unemploy "HH Source of livelihood: Unemployment benefits"
  
  label var b6_livelihood_wage "HH Source of livelihood: Wage Employment"

  # d;
  label def access
        1 "I have full access"
		2 "I have limited access"
		3 "I do not have access", modify;
  # d cr;
  label val b7 access
  label var b7 "What level of access to household money do you personally have?"
  
  # d;
  label def decision
        1 "I make the decision"
		2 "My spouse or partner"
		3 "My spouse & I"
		4 "I make the decision with someone else in my HH"
		5 "My father"
		6 "My mother"
		7 "Another man in HH"
		8 "Another woman in HH"
		9 "Someone else outside of HH"
		10 "Other(specify)", modify;	
  # d cr;
  label val b8 decision
  label var b8 "Who normally decides about large purchases in your household?"
  
  label val b9 decision
  label var b9 "Who decides money spending priorities in critical or urgent matters in your hh"

  label var c1_maincare_disability "Someone with special needs/disability"
  
  label var c1_maincare_elderly "Elderly dependent >65yo"
  
  label var c1_maincare_isolate "HH member self-isolating"
  
  label var c1_maincare_none "Not main caregiver of above"
  
  label var c1_maincare_preschool "Child/children <6yo"
  
  label var c1_maincare_school "School-aged child"
  
  # d;
  label def frequency
        1 "All of the time"
		2 "Most of the time"
		3 "Occasionally"
		4 "Rarely"
		5 "Not at all", modify;	
  # d cr;
  label val c1a frequency
  label var c1a "How often do you get help from others to take care of these family members?"

  label var c1b_another_man "Who helps caring hh memb? Another man/boy in HH"
  
  label var c1b_another_woman "Who helps caring hh memb? Another woman/girl in HH"
  
  label var c1b_father "Who helps caring hh memb? Father, in-law, step"
  
  label var c1b_mother "Who helps caring hh memb? mother, in-law, step"
  
  label var c1b_oth_fam "Who helps caring hh memb? Family outside of HH"
  
  label var c1b_other "Who helps caring hh memb? Other(specify)"
  
  label var c1b_spouse "Who helps caring hh memb? Spouse"
  
  label var c1b_worker "Who helps caring hh memb? Paid worker"
  
  label var c1c_hours_care "Number of hours per day spent on care activities for family members"
  
  # d;
  label def increasedecrease
        1 "Increased"
		2 "Stayed the same"
		3 "Decreased"
		4 "Not applicable", modify;	
  # d cr;
  
  label val c1d increasedecrease
  label var c1d "How has time you spend caring for your family changed during pandemic"
  la var c2a "Does anyone normally help you in. taking care of these household chores?"   
  
  la def c2a 1 "Yes, all the time" 2 "Yes, most of the time" ///
             3 "Yes, some of the time" 4 "Yes, rarely" 5 "No, not at all", modify 
  la val c2a c2a  
  label var c2_animals "Chores at least half of the time: tending animals"
  
  label var c2_business "Chores at least half of the time: supporting family biz"

  label var c2_clean "Chores at least half of the time: Cleaning"

  label var c2_cook "Chores at least half of the time: cooking"
  
  label var c2_farm "Chores at least half of the time: subsistence farming"
  
  label var c2_hhmanage "Chores at least half of the time: manage HH"
  
  label var c2_none "Chores at least half of the time: none of above"
  
  label var c2_other "Chores at least half of the time: other(specify)"
  
  label var c2_shop "Chores at least half of the time: shopping"
  
  label var c2_water_fuel "Chores at least half of the time: collecting water or fuel"

  label val c1a frequency
  label var c1a "Does anyone normally help you in taking care of these household chores?"

  label var c2b_another_man "Who helps with chores? Another man/boy in HH"
  
  label var c2b_another_woman "Who helps with chores? Another woman/girl in HH"
  
  label var c2b_daughter "Who helps with chores? My Daughter"
  
  label var c2b_father  "Who helps with chores? Father, in-law, step"
  
  label var c2b_mother "Who helps with chores? mother, in-law, step"
  
  label var c2b_none "Who helps with chores? No One"
  
  label var c2b_other "Who helps with chores? Other(specify)"
  
  label var c2b_son "Who helps with chores? My Son"
  
  label var c2b_spouse "Who helps with chores? Spouse"
  
  label var c2b_worker "Who helps with chores? Paid worker"
  
  label var c2c_hours_chores "Number of hours per day spent on household chores"
  
  label val c2d increasedecrease
  label var c2d "How did  time on household chores change during the pandemic"
 
  label val c3 likert_scale
  label var c3 "A woman's most important role is to take care of her home and children"

  label var c4_housewife_other "How many neighbs believe a woman's most important role is care of home and children"

  # d;
  label def hours1
        0 "0 to 2 hours per day"
        1 "3 hours per day"
		2 "4 to 5 hours per day"
		3 "6 to 9 hours per day"
		4 "10 to 15 hours per day"
		5 "16 to 24 hours per day", modify;	
  # d cr;
  label val carehr_cat hours1
  label var carehr_cat "Number of hours per day spent on family member care activities - Categorical"
  
  # d;
  label def hours2
        0 "0 hours per day"
        1 "1 hour per day"
		3 "2 hours per day"
		4 "3 hours per day"
		5 "4 hours per day "
		6 "5 to 6 hours per day"
		7 "7 to 20 hours per day", modify;	
  # d cr;
  label val chorehr_cat hours2
  label var chorehr_cat "Number of hours per day spent on household chores - Categorical"
  
  label val d0 yesno
  label var d0 "Do you have a long-term partner or a spouse?"
  
  # d;
  label def n_people
        1 "0, I live alone"
        2 "1 person"
		3 "2-5 people"
		4 "6-10 people"
		5 "11 or more", modify;	
  # d cr;
  label val d1 n_people
  label var d1 "How many other people live with you under same roof? do not count yrself"

  la var d2_r "Age"
  la def age 1 "24 years old or younger" 2 "25 - 64 years old"  3 "65 years old or older", modify 
  la val d2_r age
  
  # d;
  label def education        
        1 "Secondary or less"
		2 "More than secondary", modify;	
  # d cr;
  label val d3_r education
  label var d3_r "Educational level - Recoded"
  
  label var d4_own_computer "Own a computer"
  
  label var d4_own_home "Own place where you live"
  
  label var d4_own_land "Own land"
  
  label var d4_own_none "Own none of above"
  
  label var d4_own_phone "Own a Smart Phone"
  
  label var d4_own_vehicle "Own motrized vehicle"
  
  label val d5 likert_scale
  label var d5 "There are times when I feel uncomfortable or even unsafe in my house"
  
  label var d6_health "Experienced because of COVID-19: Unable to seek medical care"
  
  label var d6_isolate "Experienced because of COVID-19: follow a quarantine order"
  
  label var d6_job "Experienced because of COVID-19: lost a job"
  
  label var d6_medical "Experienced because of COVID-19: difficulty accessing medical or hygiene supply"
  
  label var d6_migrate "Experienced because of COVID-19: migrated"
  
  label var d6_none "Experienced because of COVID-19: none of the above"
  
  label var d6_other "Experienced because of COVID-19: other"
  
  label var d6_personal "Experienced because of COVID-19: unable to perform personal care/health routine"
  
  label var d6_school "Experienced because of COVID-19: School cancelled/reduced"
  
  label var d6_transport "Experienced because of COVID-19: lost access to public transport"
  
  label var d6_wait "Experienced because of COVID-19: longer wait time so seek medical care"
  
  label var d7_bored "Main concerns: staying home with limited things to do"
  
  label var d7_food "Main concerns: having enough food & supplies"
  
  label var d7_health "Main concerns: access to health care"
  
  label var d7_info "Main concerns: access to accurate information on COVID-19"
  
  label var  d7_loan "Main concerns: repaying loans"
  
  label var d7_money "Main concerns: having enough money to sustatin fam."
  
  label var d7_none "Main concerns: None at this time"
  
  label var d7_other "Main concerns: Other(specify)"

  label var d7_stuck "Main concerns: stuck at home for long time"
  
  label var d7_work "Main concerns: the future of my work"
  
  # d;
  label def status 
        1 "I am a student"
        2 "I am a business owner or manager"
		3 "I support a family business"
		4 "I work for wage or salary"
		5 "Stay at home parent"
		6 "Unemployed"
		7 "Retired"
		8 "Apprentice/trainee/intern"
		9 "Unpaid caregiver for family member"
		10 "Other(Specify)", modify;	
  # d cr;
  label val d8 status
  label var d8 "Which of the following best describe your main status since January 1st, 2020?"

  label var language "Survey Language"
  
  label var pct_online_cat "Percent of population online"
  
  # d;
  label def pct_online_cat 
        1 "5% or less"
        2 "5 to 10%"
        3 "10 to 15%"
        4 "15 to 20%"
        5 "20 to 25%"
        6 "25 to 30%"
        7 "30 to 35%"
        8 "35 to 40%"
        9 "40 to 45%"
        10 "45 to 50%"
        11 "50 to 55%"
        12 "55 to 60%"
        13 "60 to 65%"
        14 "65 to 70%"
        15 "70 to 75%"
        16 "75 to 80%"
        17 "80 to 85%"
        18 "85 to 90%"
        19 "90 to 95%"
        20 "95 to 100%", modify;       	
  # d cr;
  label val pct_online_cat pct_online_cat
  label var pct_online_cat "Percent of population online"

  # d;
  label def regions 
        1 "East Asia & Pacific"
        2 "Europe & Central Asia"
        3 "Latin America & Caribbean"
        4 "Middle East & North Africa"
        5 "North America"
        6 "South Asia"
		7 "Sub-Saharan Africa", modify;
  # d cr;
  label val region regions
  label var region "Region Name"
  
  label var sub_region "Sub-Regional location / Country Name"
  
  label var w_region	"Regional Weight"

  label var w_subregion	"Sub-regional/Country Weight"
  
  # d;
  label def workhr_cat
        0 "0 to 2 hours per day"
        3 "3 to 4 hours per day"
        5 "5 to 7 hours per day"
        8 "8 hours per day"
        9 "9 to 11 hours per day"
        12 "12 to 14 hours per day"
        15 "15 to 24 hours per day", modify;
  # d cr;
  label val workhr_cat workhr_cat
  label var workhr_cat	"Number of hours spent per day at work last week - Categorical"

 
** 2.3) Dealing with missing values and N/A
** ---------------------------------------
/* Note:For this follow the skip patterns in the codebook*/
	qui ds, has(type  string)
	foreach var of varlist `r(varlist)'{
	replace `var'=".n" if `var'=="NA"
	}
   /* Here we are going to replace by =.d Dont answered
      if the variable is currently equal to 
      =.n (not applicable) but it should have been answered according to the 
      display logic.*/   
	



** 2.5) String variables to numeric 
** --------------------------------------------	  
   /* i.e.b1_hours_work*/
   

   
** 2.7) Setting up globals that containg the set of variables that should be answer 
   * by each type of respondent
   * ---------------------------------------------------------------------------

}

********************************************************************************
*         PART 3.  Individual variables cleaning and sample selection
********************************************************************************
if $part_3{
  replace language="France - French" if language=="France - Feench"
  * Run dofile for cleaning code iso3 
  do "$dofiles/Cleaning/Code_iso3_cleaning.do"	
  codebook code_iso3	

** 	Merging with WVS // Activate this if need to merge with WVS 
**  However, we will focus on this in the construction of variables dofile
*** ------------------------------------------------------------------
if 0{
 preserve 
 * Load Dataset 
   use "$data/Raw/WVS_Longitudinal_1981_2020_var.dta", clear
   keep if S002==6
   
 * Recoding the variables so a higher number implies more gen eq 
   la def agree_disg3 1 "Disagree" 2 "Neither" 3 "Agree", modify 
   la def agree_disg4 1 "Strongly Disagree"  2 "Disagree" 3 "Agree"  4 "Agree Strongly", modify
   
   recode C001 (1=3) (2=1) (3=2)
   recode D063_B  D066_B (1=3) (3=1)
   recode D078 (1=4) (2=3) (3=2) (4=1)

   la val C001 D063_B  D066_B agree_disg3
   la val D078 D061 D062 agree_disg4 
   
  * Collapsing by gender and country  
    drop D063 D066
	ren  D063_B  D063
	ren  D066_B  D066
	
    gl var_col C001 D059 D060 D061 D063  D066 D078 
	foreach var of varlist $var_col{
	tabulate `var', gen (d_`var'_)		
	}
    drop if female_resp==. 
		
	gen d_wkgmoth_child=(d_D061_3==1 | d_D061_4==1)	
	replace d_wkgmoth_child=. if  D061>=. 
	gen d_womearnsmore=(d_D066_3==1)
	replace d_womearnsmore=. if D066>=. 
	
		
	gl var_col C001 D019  D059 D060 D061 D063 D066 D078 d_C001_1-d_D078_4 ///
	           d_wkgmoth_child d_womearnsmore
    collapse $var_col, by(COUNTRY_ALPHA female_resp)
  * Reshaping dataset 
	reshape wide $var_col, i(COUNTRY_ALPHA) j(female_resp)
	
  * Adding labels Male Variables
	local respondent Male 
	local code 0
	la var C001`code'   "(`respondent')Jobs scarce: Men should have more right to a job than women"
	la var D059`code'   "(`respondent')Men make better political leaders than women do"
	la var D060`code'   "(`respondent')University is more important for a boy than for a girl"
	la var D063`code'   "(`respondent')Job best way for women to be independent"
	la var D066`code'   "(`respondent')Problem if women have more income than husband"
	la var D078`code'   "(`respondent')Men make better business executives than women do"
	la var 	d_C001_1`code'  "(`respondent')Disagree:Men should have more right to a job than women"
	la var 	d_C001_2`code'  "(`respondent')Neither:Men should have more right to a job than women"
	la var 	d_C001_3`code'  "(`respondent')Agree:Men should have more right to a job than women"
	la var 	d_D059_1`code'  "(`respondent')Strong Disagree:Men make better political leaders than women do"
	la var 	d_D059_2`code'  "(`respondent')Disagree:Men make better political leaders than women do"
	la var 	d_D059_3`code'  "(`respondent')Agree:Men make better political leaders than women do"
	la var 	d_D059_4`code'  "(`respondent')Strong Agree:Men make better political leaders than women do"
	la var 	d_D060_1`code'  "(`respondent')Strong Disagree:University is more important for a boy than for a girl"
	la var 	d_D060_2`code'  "(`respondent')Disagree:University is more important for a boy than for a girl"
	la var 	d_D060_3`code'  "(`respondent')Agree:University is more important for a boy than for a girl"
	la var 	d_D060_4`code'  "(`respondent')Strong Agree:University is more important for a boy than for a girl"
	la var 	d_D063_1`code'  "(`respondent')Disagree:Job best way for women to be independent"
	la var 	d_D063_2`code'  "(`respondent')Neither:Job best way for women to be independent"
	la var 	d_D063_3`code'  "(`respondent')Agree:Job best way for women to be independent"
	la var 	d_D066_1`code'  "(`respondent')Disagree:Problem if women have more income than husband"
	la var 	d_D066_2`code'  "(`respondent')Neither:Problem if women have more income than husband"
	la var 	d_D066_3`code'  "(`respondent')Agree:Problem if women have more income than husband"
	la var 	d_D078_1`code'  "(`respondent')Strong Disagree:Men make better business executives than women do"
	la var 	d_D078_2`code'  "(`respondent')Disagree:Men make better business executives than women do"
	la var 	d_D078_3`code'  "(`respondent')Neither:Men make better business executives than women do"
	la var 	d_D078_4`code'  "(`respondent')Strong Agree:Men make better business executives than women do"
    la var  D061`code'      "(`respondent')Pre-school child suffers with working mother"
    la var  d_D061_1`code' "(`respondent')Strong Disagree:Pre-school child suffers with working mother"	
    la var  d_D061_2`code'  "(`respondent')Disagree: Pre-school child suffers with working mother"	
    la var  d_D061_3`code'  "(`respondent')Agree: Pre-school child suffers with working mother"
    la var  d_D061_4`code'  "(`respondent')Strong Agree: Pre-school child suffers with working mother"		
	


	
	
  * Adding labels Male Variables
	local respondent Female 
	local code 1
	la var C001`code'   "(`respondent')Jobs scarce: Men should have more right to a job than women"
	la var D059`code'   "(`respondent')Men make better political leaders than women do"
	la var D060`code'   "(`respondent')University is more important for a boy than for a girl"
	la var D063`code'   "(`respondent')Job best way for women to be independent"
	la var D066`code'   "(`respondent')Problem if women have more income than husband"
	la var D078`code'   "(`respondent')Men make better business executives than women do"
	la var 	d_C001_1`code'  "(`respondent')Disagree:Men should have more right to a job than women"
	la var 	d_C001_2`code'  "(`respondent')Neither:Men should have more right to a job than women"
	la var 	d_C001_3`code'  "(`respondent')Agree:Men should have more right to a job than women"
	la var 	d_D059_1`code'  "(`respondent')Strong Disagree:Men make better political leaders than women do"
	la var 	d_D059_2`code'  "(`respondent')Disagree:Men make better political leaders than women do"
	la var 	d_D059_3`code'  "(`respondent')Agree:Men make better political leaders than women do"
	la var 	d_D059_4`code'  "(`respondent')Strong Agree:Men make better political leaders than women do"
	la var 	d_D060_1`code'  "(`respondent')Strong Disagree:University is more important for a boy than for a girl"
	la var 	d_D060_2`code'  "(`respondent')Disagree:University is more important for a boy than for a girl"
	la var 	d_D060_3`code'  "(`respondent')Agree:University is more important for a boy than for a girl"
	la var 	d_D060_4`code'  "(`respondent')Strong Agree:University is more important for a boy than for a girl"
	la var 	d_D063_1`code'  "(`respondent')Disagree:Job best way for women to be independent"
	la var 	d_D063_2`code'  "(`respondent')Neither:Job best way for women to be independent"
	la var 	d_D063_3`code'  "(`respondent')Agree:Job best way for women to be independent"
	la var 	d_D066_1`code'  "(`respondent')Disagree:Problem if women have more income than husband"
	la var 	d_D066_2`code'  "(`respondent')Neither:Problem if women have more income than husband"
	la var 	d_D066_3`code'  "(`respondent')Agree:Problem if women have more income than husband"
	la var 	d_D078_1`code'  "(`respondent')Strong Disagree:Men make better business executives than women do"
	la var 	d_D078_2`code'  "(`respondent')Disagree:Men make better business executives than women do"
	la var 	d_D078_3`code'  "(`respondent')Neither:Men make better business executives than women do"
	la var 	d_D078_4`code'  "(`respondent')Strong Agree:Men make better business executives than women do"
    la var  D061`code'      "(`respondent')Pre-school child suffers with working mother"
    la var  d_D061_1`code' "(`respondent')Strong Disagree:Pre-school child suffers with working mother"	
    la var  d_D061_2`code'  "(`respondent')Disagree: Pre-school child suffers with working mother"	
    la var  d_D061_3`code'  "(`respondent')Agree: Pre-school child suffers with working mother"
    la var  d_D061_4`code'  "(`respondent')Strong Agree: Pre-school child suffers with working mother"			
	
  * Checking country id isid 
	isid COUNTRY_ALPHA
	
  * Saving temporaty dataset 
    ren COUNTRY_ALPHA code_iso3
    tempfile wvs_data
    save `wvs_data'	
 restore  

 * Merge with Wolrd value survey
   merge m:1 code_iso3 using  `wvs_data', nogenerate keep(master matched)
}
 ** Cleaning some missing code iso 3
 replace code_iso3="AUS" if sub_region =="Australia"
 replace code_iso3="BEN" if sub_region =="Benin"
 replace code_iso3="BIH" if sub_region =="Bosnia & Herzegovina"
 replace code_iso3="KHM" if sub_region =="Cambodia"
 replace code_iso3="CMR" if sub_region =="Cameroon"
 replace code_iso3="DJI" if sub_region =="Djibouti"
 replace code_iso3="ETH" if sub_region =="Ethiopia"
 replace code_iso3="FIN" if sub_region =="Finland"
 replace code_iso3="GIN" if sub_region =="Guinea"
 replace code_iso3="CIV" if sub_region =="Ivory Coast"
 replace code_iso3="MNG" if sub_region =="Mongolia"
 replace code_iso3="QAT​" if sub_region =="Qatar"
  
* Drop sample out of our analysis to be able to create a dataset 
* ready for analysis and that can be share for replication 
  drop if a4>=.   
  
* Save  
 saveold "$data/Intermediate/GenderAtHome_DataClean.dta", replace 
}