* **************************************************************************** *
* **************************************************************************** *
* Breadwinners and Caregivers: Examining the Global Relationship between       *
* Gender Norms and Economic Behavior                                           *
* Replication File                                                             *
* PART 2: Master Dofile for Data Variable Construction                                    *
* 2024                                                                         *
* **************************************************************************** *
* **************************************************************************** *
/*
* Author: Paula Gonzalez
* Program Purpose: This master dofile is designed for preparing the 
*                  clean dataset from the 'Gender at Home' project. It includes 
*                  variable construction, merging with additional datasets (e.g., 
*                  Oxford data), generating specific weights, and creating a 
*                  country-level dataset for analysis.
* Description: Key tasks performed by this dofile include:
*              - Creating copies of original variables with more intuitive names.
*              - Ordering variables to align with their counterparts in the 
*                codebook and ensuring a logical sequence.
*              - Generating dummies from categorical variables with the naming 
*                convention 'd_categoricalvariablename_*', where '*' represents 
*                the category number.
*              - Labelling newly created variables.
*              - Renaming overlapping variables with the FOB dataset for 
*                consistency and ease of comparison.
* Date last reviewed: January 2024
*------------------------------------------------------------------------------*
* Datasets Required: 
* - Data 1 GenderAtHome_DataClean: Cleaned Gender At Home dataset in Stata format
                                   for sample analysis.
*
* Unique Identifier: 
* - The dataset has been de-identified in line with the agreement with Facebook. 
*   It includes only country-level codes and no individual identifiers.
*
* Outline: 
*  Part 1. Construction of Individual Variables
*  Part 2. Merging with Other Data
*  Part 3. Generating Regression Weights for Saving
*  Part 4. Collapsing Data at the Country Level
*  Part 5. Generating dataset for maps
*/

********************************************************************************
*                       PREPARATION AND MAIN SETTINGS 
********************************************************************************
if 1{
   * Define sections to execute
   * ---------------------------
   global part_1   1      // Construction of Individual Variables
   global part_2   1      // Merging with Other Data
   global part_3   1      // Generating Regression Weights
   global part_4   1      // Creating Country-Level Dataset
   global part_5   1      // Creating Dataset for Maps
   
 * Load Dataset 
   use "$data/Intermediate/GenderAtHome_DataClean.dta", clear

}

********************************************************************************
*         PART 1.  Construction of Individual Variables 
********************************************************************************
if $part_1 {
   do "$dofiles/Intermediate/Sections/Part1_ConstructionIndividualVariables.do"
}

********************************************************************************
*         PART 2.  Merging with Other Datasets 
********************************************************************************
if $part_2 {
   do "$dofiles/Intermediate/Sections/Part2_MergingOtherData.do"
}
 
********************************************************************************
*      PART 3.  Generating Regression Weights and sample selection variables 
********************************************************************************
if $part_3 {
   do "$dofiles/Intermediate/Sections/Part3_PredictedInverseProbabilities.do"  
  
 * Save the dataset at the individual level 
   drop if country_num>=. // double check this 
   saveold "$data/Final/GenderAtHome_DataAnalysisInd.dta", replace 

}

********************************************************************************
*         PART 4.  Creating Country-Level Dataset 
********************************************************************************
if $part_4 {
   do "$dofiles/Intermediate/Sections/Part4_CountryLevelData.do"

   * Save the country-level dataset 
   saveold "$data/Final/GenderAtHome_DataAnalysisCountry.dta", replace
}

********************************************************************************
*         PART 5.  Creating Dataset for Maps
********************************************************************************
if $part_5{
   do "$dofiles/Intermediate/Sections/Part5_MapsData.do"	
  
 * Save dataset with coordiantes to create maps
   saveold "$data/Final/GenderAtHome_DataAnalysisMaps.dta", replace	
}


********************************************************************************
// END OF DOFILE 